@@ -148,7 +148,7 @@ void DummyTest::testFetch()
     QCOMPARE(m_appBackend->property("startElements").toInt()*2, resources.count());
 
     //fetches updates, adds new things
-    m_appBackend->messageActions().at(0)->trigger();
+    m_appBackend->checkForUpdates();
     QSignalSpy spy(m_model, SIGNAL(allInitialized()));
     QVERIFY(spy.wait(80000));
     auto resources2 = fetchResources(m_appBackend->search({}));
