@@ -58,12 +58,17 @@ class PackageKitResource : public AbstractResource
         QString installedPackageId() const;
         QString availablePackageId() const;
 
+        void clearPackageIds() { m_packages.clear(); }
+
         QMap<PackageKit::Transaction::Info, QStringList> packages() const { return m_packages; }
 
         PackageKitBackend* backend() const;
 
         static QString joinPackages(const QStringList& pkgids);
 
+        void invokeApplication() const override {}
+        bool canExecute() const override { return false; }
+
     public Q_SLOTS:
         void addPackageId(PackageKit::Transaction::Info info, const QString &packageId, bool arch);
         void setDetails(const PackageKit::Details& details);
