@@ -36,21 +36,6 @@ AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     connect(this, &AbstractResource::stateChanged, this, &AbstractResource::reportNewState);
 }
 
-bool AbstractResource::canExecute() const
-{
-    return !executables().isEmpty();
-}
-
-void AbstractResource::invokeApplication() const
-{
-    QStringList exes = executables();
-    if(!exes.isEmpty()) {
-        const QString exe = exes.at(0);
-        auto args = KShell::splitArgs(exe);
-        QProcess::startDetached(args.takeFirst(), args);
-    }
-}
-
 bool AbstractResource::isTechnical() const
 {
     return false;
@@ -92,11 +77,6 @@ QStringList AbstractResource::mimetypes() const
     return QStringList();
 }
 
-QStringList AbstractResource::executables() const
-{
-    return QStringList();
-}
-
 AbstractResourcesBackend* AbstractResource::backend() const
 {
     return static_cast<AbstractResourcesBackend*>(parent());
