@@ -49,7 +49,7 @@ ResultsStream::ResultsStream(const QString &objectName, const QVector<AbstractRe
     QTimer::singleShot(0, this, [resources, this] () {
         if (!resources.isEmpty())
             Q_EMIT resourcesFound(resources);
-        deleteLater();
+        finish();
     });
 }
 
@@ -63,6 +63,11 @@ ResultsStream::~ResultsStream()
 {
 }
 
+void ResultsStream::finish()
+{
+    deleteLater();
+}
+
 AbstractResourcesBackend::AbstractResourcesBackend(QObject* parent)
     : QObject(parent)
 {
